<?php

namespace Regreg\Ertgretg\Providers;

use Illuminate\Support\ServiceProvider;
use Regreg\Ertgretg\Ertgretgs;

class ErtgretgServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'ertgretg');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'ertgretg');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Regreg\Ertgretg\Providers\AuthServiceProvider::class);
        $this->app->register(\Regreg\Ertgretg\Providers\RouteServiceProvider::class);
        // $this->app->register(\Regreg\Ertgretg\Providers\EventServiceProvider::class);
        // $this->app->register(\Regreg\Ertgretg\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('regreg.ertgretg', function($app)
        {
            return $this->app->make(Ertgretgs::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Https://callgirlguwahati.com to repository
        $this->app->bind(
            'Regreg\Ertgretg\Interfaces\Https://callgirlguwahati.comRepositoryInterface',
            \Regreg\Ertgretg\Repositories\Eloquent\Https://callgirlguwahati.comRepository::class
        );
    }


    /**
     * Merges user's and ertgretg's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'regreg.ertgretg'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Regreg\Ertgretg\Commands\Ertgretg::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['regreg.ertgretg'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('regreg/ertgretg.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/ertgretg')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/ertgretg')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
